@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.24
+# Version   : 0.3.27
 
 from operator import contains
 import  numpy                   as      np
@@ -651,6 +651,18 @@ class AFM:
             _approach = self.approach[:,i]
             _retract = self.retract[:,i]
             _z = self.z_approach[:,i]
+            _z_retract = self.z_withdraw[:,i]
+
+            force = np.append(np.flip(_approach), _retract)
+            distance = np.append(np.flip(_z), _z_retract)
+            
+            distance = distance[~np.isnan(force)]
+            force = force[~np.isnan(force)]
+
+            idx = np.nanargmax(force)
+
+            _approach = np.flip(force[:idx+1])
+            _z = np.flip(distance[:idx+1])
 
             try:
                 j = 0
@@ -1630,7 +1642,7 @@ class AFM:
             x_pos = x_pos * x_scale/x_cells
             y_pos = y_pos * y_scale/y_cells
 
-            height = height - height[0]
+            height = height - height.min()
 
             if plot == 'adhesion':
                 plt_title = 'Adhesion (nN)'
